%{?!lua_version:%global lua_version 5.4}

%define url_ver %(echo %{version} | cut -d. -f1,2)

%define subrel 1

Summary:	Reliable High Performance TCP/HTTP Load Balancer
Name:		haproxy
Version:	2.8.14
#% define     subrel 1
Release:	%mkrel 1
License:	GPLv2 and LGPLv2
Group:		System/Servers
URL:		https://www.haproxy.org
Source0:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz
Source1:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz.sha256
Source2:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz.md5
Source3:	%{name}.service
Source4:	%{name}.tmpfiles
Source5:	%{name}.logrotate
Source6:	%{name}.sysconfig
Source7:	%{name}.conf
Source8:	%{name}.check
Patch0:		haproxy-2.8.0-rapsys-key-private.patch
Patch1:		haproxy-2.8.4-quic.patch
Patch2:		haproxy-2.8.3-rapsys-fix-log-append.patch
Patch3:		haproxy-2.8.4-rapsys-buffered-stdout.patch
#CVE-2025-32464
Patch4: 	https://github.com/haproxy/haproxy/commit/3e3b9eebf871510aee36c3a3336faac2f38c9559.patch
%ifarch armv7hl aarch64
BuildRequires:	libatomic-devel
%endif
Requires(pre):	shadow-utils
Requires(pre):	rpm-helper
Requires(post):	hostname openssl rpm-helper
Requires(postun):	rpm-helper
BuildRequires:	pcre2-devel
BuildRequires:	pkgconfig(libcrypt)
BuildRequires:	pkgconfig(lua) >= %{lua_version}
BuildRequires:	pkgconfig(openssl-quic)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	perl
BuildRequires:	apg
Requires:	lua%{lua_version}
Requires:	haproxy-server = %{version}-%{release}
Requires(postun):	update-alternatives
Requires(posttrans):	update-alternatives

%description
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient.

%package noquic
Summary:	Reliable High Performance TCP/HTTP Load Balancer
Group:		System/Servers
Provides:	haproxy-server = %{version}-%{release}
Requires:	haproxy = %{version}-%{release}
Requires:	libgcc1

%description noquic
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient. Build without QUIC protocol support.

This HAProxy binary is linked to openssl without QUIC protocol support.

%package quic
Summary:	Reliable High Performance TCP/HTTP Load Balancer
Group:		System/Servers
Provides:	haproxy-server = %{version}-%{release}
Requires:	haproxy = %{version}-%{release}
Requires:	libgcc1

%description quic
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient. Build with QUIC protocol support.

This HAProxy binary is linked to quictls with QUIC protocol support.

%package utils
Summary:	Utilities for working with HAProxy servers
Group:		Networking/Other

%description utils
HAProxy-utils contains a couple of command line utilities for working with
haproxy servers.

You should install haproxy-utils if you need to get information from HAProxy
servers.

%prep
%autosetup -p1

%build
# Build haproxy noquic and quic
#TODO: add USE_SLZ="1" ? (stateless library with less overhead than zlib for http servers)
#XXX: see http://www.libslz.org/
for QUIC in "" "1"; do
%make_build \
	CFLAGS="%{build_cflags} -fwrapv" \
	LDFLAGS="%{build_ldflags}" \
	CPU="generic" \
	TARGET="linux-glibc" \
	USE_LUA="1" \
	LUA_LIB="%{lua_libdir}" \
	LUA_INC="%{_includedir}/lua" \
	USE_CRYPT_H="1" \
	USE_DL="1" \
	USE_EPOLL="1" \
	USE_GETADDRINFO="1" \
	USE_LIBCRYPT="1" \
	USE_LINUX_SPLICE="1" \
	USE_LINUX_TPROXY="1" \
	USE_NS="1" \
	USE_OPENSSL="1" \
	USE_PCRE2="1" \
	USE_PCRE2_JIT="1" \
	USE_PROMEX="1" \
	USE_PTHREAD_PSHARED="1" \
	USE_QUIC="${QUIC}" \
	USE_RT="1" \
	USE_SYSTEMD="1" \
	USE_TFO="1" \
	USE_THREAD="1" \
	USE_THREAD_DUMP="1" \
	USE_TPROXY="1" \
	USE_ZLIB="1" \
	PREFIX=%{_prefix} \
	MANDIR=%{_mandir} \
	DOCDIR=%{_pkgdocdir} \
	PCRE2_LIB=%{_libdir};
done

# Build utils
%make_build \
	CFLAGS="%{build_cflags} -fwrapv" \
	LDFLAGS="%{build_ldflags}" \
	admin/halog/halog \
	admin/iprange/iprange \
	dev/tcploop/tcploop \
	dev/poll/poll \
	dev/flags/flags \
	dev/hpack/{decode,gen-enc,gen-rht}

%install
for QUIC in "" "1"; do
%make_install \
	USE_QUIC="${QUIC}" \
	PREFIX=%{_prefix} \
	MANDIR=%{_mandir} \
	DOCDIR=%{_pkgdocdir};
done

# Install sysconfdirs
install -d 0755 %{buildroot}%{_sysconfdir}
install -d 0755 %{buildroot}%{_sysconfdir}/%{name}
install -d 0755 %{buildroot}%{_sysconfdir}/sysconfig

# Install shared state dir
install -d 0755 %{buildroot}%{_sharedstatedir}/%{name}

# Install service
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

# Install tmpfiles
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# Install log rotation stuff
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Install sysconfig
install -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# Install configuration
#TODO: implement https://github.com/janeczku/haproxy-acme-validation-plugin/blob/master/acme-http01-webroot.lua ?
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Install check
install -D -p -m 0755 %{SOURCE8} %{buildroot}%{_sbindir}/haproxy-check

# Replace admin password
perl -pne 's/ADMINPASSWORD/SECUREME!/' -i %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Replace operator password
perl -pne 's/OPERATORPASSWORD/SECUREME!/' -i %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Copy errors files
cp -r examples/errorfiles %{buildroot}%{_pkgdocdir}/error

# Install vim syntax
install -D -p -m 0644 admin/syntax-highlight/%{name}.vim %{buildroot}%{_datadir}/vim/syntax/%{name}.vim

# Install README.urpmi
cat << EOF | perl -pe 'chomp if eof' > README.urpmi
Haproxy is now installed.

Configuration file is %{_sysconfdir}/%{name}/%{name}.conf

The server listen on any:8000, 8080 and 8443 by default.

Add to %{_sysconfdir}/shorewall/rules.haproxy these shorewall rules for a transparent proxy:
# Redirect tcp traffic from net on port 80 to 8000
REDIRECT	net	8000	tcp	80
# Redirect tcp traffic from net on port 443 to 8000
REDIRECT	net	8000	tcp	443
# Redirect udp traffic from net on port 443 to 8443
#REDIRECT	net	8443	udp	443

Enable the service with:
# systemctl enable haproxy.service

Start the service with:
# systemctl start haproxy.service
EOF

# Install log dir
install -d -m 755 %{buildroot}%{_logdir}/%{name}

# Install bin dir
install -d 0755 %{buildroot}%{_bindir}

# Install haproxy utils
install -p -m 0755 admin/halog/halog %{buildroot}%{_bindir}/halog
install -p -m 0755 admin/iprange/iprange %{buildroot}%{_bindir}/iprange
install -p -m 0755 dev/flags/flags %{buildroot}%{_bindir}/flags
install -p -m 0755 dev/poll/poll %{buildroot}%{_bindir}/poll
install -p -m 0755 dev/tcploop/tcploop %{buildroot}%{_bindir}/tcploop
install -p -m 0755 dev/hpack/gen-rht %{buildroot}%{_bindir}/gen-rht
install -p -m 0755 dev/hpack/gen-enc %{buildroot}%{_bindir}/gen-enc
install -p -m 0755 dev/hpack/decode %{buildroot}%{_bindir}/hadecode

%pre
%_pre_useradd %{name} %{_sharedstatedir}/%{name} /bin/false
%_pre_groupadd %{name} %{name}

%preun
%_preun_service %{name}

%post
%_tmpfilescreate %{name}
%_post_service %{name}
%_create_ssl_certificate %{name} -g %{name}

%postun
%_postun_userdel %{name}
%_postun_groupdel %{name}

%posttrans noquic
%{_sbindir}/update-alternatives --install %{_sbindir}/haproxy haproxy %{_sbindir}/haproxy-noquic 10

%postun noquic
if [ "$1" -eq "0" ]; then
	%{_sbindir}/update-alternatives --remove haproxy %{_sbindir}/haproxy-noquic
fi

%posttrans quic
%{_sbindir}/update-alternatives --install %{_sbindir}/haproxy haproxy %{_sbindir}/haproxy-quic 20

%postun quic
if [ "$1" -eq "0" ]; then
	%{_sbindir}/update-alternatives --remove haproxy %{_sbindir}/haproxy-quic
fi

%files
%doc README.urpmi
%dir %{_logdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sbindir}/haproxy-check
%{_pkgdocdir}/*.txt
%{_pkgdocdir}/error/*
%{_mandir}/man1/*
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_datadir}/vim/syntax/%{name}.vim
%attr(0750, %{name}, %{name}) %{_sharedstatedir}/%{name}

%files noquic
%{_sbindir}/%{name}-noquic

%files quic
%{_sbindir}/%{name}-quic

%files utils
%{_bindir}/flags
%{_bindir}/gen-enc
%{_bindir}/gen-rht
%{_bindir}/hadecode
%{_bindir}/halog
%{_bindir}/iprange
%{_bindir}/poll
%{_bindir}/tcploop


%changelog
* Wed Apr 23 2025 katnatek <katnatek> 2.8.14-1.1.mga9
+ Revision: 2178341
- Add patch for CVE-2025-32464 mga#34186
+ rapsys <rapsys>
- Version 2.8.14
- Version 2.8.13
- Fix doc
- Fix doc
- Version 2.8.12
- Version 2.8.11
- Version 2.8.10
- Version 2.8.9
- Version 2.8.7
- Version 2.8.6
- Version 2.8.5
- Version 2.8.4
- Fix invalid fd flag reset to prevent log corruption
  Haproxy service check script to get errors
- Fix invalid fd flag reset to prevent log corruption
- Haproxy service check script
- Remove double CAP_NET_BIND_SERVICE definition
  Haproxy service check script
- Add CAP_NET_BIND_SERVICE capability to allow binding to privileged ports
- Add commented out X-Backend and QUIC header
  Check backend by default
  Fix typo
  Fix circular loop which trigger invalid log
- Add required rpm helper by triggers
  Add required libgcc1 dependancy
  Create ssl certificate with haproxy group
  Bump release
- Add missing README.urpmi doc
- Bump release for security update
- Fix release version
- Prevent .rpmnew on update
  Remove admin and operator access by default
  Remove admin action access by default
- Version 2.8.3 (add missing tarball)
- Version 2.8.3

* Mon Jul 10 2023 rapsys <rapsys> 2.8.1-4.mga9
+ Revision: 1963827
- Fix postun requires

* Mon Jul 10 2023 rapsys <rapsys> 2.8.1-3.mga9
+ Revision: 1963823
- Remove useless suggests

* Mon Jul 10 2023 rapsys <rapsys> 2.8.1-2.mga9
+ Revision: 1963819
- Add noquic as suggests

* Mon Jul 10 2023 rapsys <rapsys> 2.8.1-1.mga9
+ Revision: 1963799
- Add haproxy-quic and haproxy-noquic packages that provide alternatives for required haproxy-server
  New quic patch set program name and ssl library to link against based on USE_QUIC value
  Version 2.8.1
- Version 2.8.1
- Version 2.8.1
- Base main program name and ssl libs to link to based on USE_QUIC value
- Allow traversing run directory for other

* Tue Jun 20 2023 rapsys <rapsys> 2.8.0-1.mga9
+ Revision: 1962602
- Add commented out QUIC sample config
- Version 2.8.0 (lts)

* Mon Jun 12 2023 rapsys <rapsys> 2.6.14-1.mga9
+ Revision: 1961835
- Version 2.6.14

* Wed May 03 2023 rapsys <rapsys> 2.6.13-1.mga9
+ Revision: 1955658
- Version 2.6.13

* Wed Apr 26 2023 rapsys <rapsys> 2.6.12-1.mga9
+ Revision: 1954978
- Version 2.6.12

* Sat Mar 25 2023 rapsys <rapsys> 2.6.11-1.mga9
+ Revision: 1950324
- Version 2.6.11
- Add log global and commented compression options
- Use restart, with only reload systemd log are not rotated
- Readd dropped optional quic patch, plz keep it

* Thu Feb 16 2023 bcornec <bcornec> 2.6.9-1.mga9
+ Revision: 1943377
- Fix mga#31557 CVE-2023-0056 and CVE-2023-25725 by updating to upstream haproxy 2.6.9
+ rapsys <rapsys>
- Replace quictls hardcoded value with pkg-config one
- Add quic patch for new quictls include dir and libnames
  Update to version 2.6.7

* Sat Dec 03 2022 rapsys <rapsys> 2.6.7-1.mga9
+ Revision: 1915588
- Update to 2.6.7, the latest 2.6 LTS
- Cleanup quic toggleable build flag
- Add with quic toggleable build flag

* Sat Oct 22 2022 rapsys <rapsys> 2.6.6-1.mga9
+ Revision: 1898437
- Update to version 2.6.6
- Cleanup personnal stuff and fix configuration for 2.6.6
- Cleanup

* Thu Sep 15 2022 rapsys <rapsys> 2.6.5-2.mga9
+ Revision: 1888956
- Add -fwrapv to build CFLAGS to make version 2.6.5 working
- Cleanup personnal domain name and fix configuration for 2.6.5

* Tue Sep 13 2022 wally <wally> 2.6.5-1.mga9
+ Revision: 1887556
- new version 2.6.5
- rediff extra private PEM keys patch (based on work from papoteur)
- rebuild for openssl 3.0.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Sep 18 2021 bcornec <bcornec> 2.4.4-1.mga9
+ Revision: 1745678
- Update to upstream haproxy 2.4.4

* Sat Aug 21 2021 wally <wally> 2.4.3-1.mga9
+ Revision: 1742137
- new version 2.4.3
- fixes CVE-2021-3924[0-2] (mga#29381)
- build using our compiler and linker flags
- fix lua requires

* Mon Aug 02 2021 rapsys <rapsys> 2.4.2-5.mga9
+ Revision: 1738533
- Fix apg subset

* Mon Aug 02 2021 rapsys <rapsys> 2.4.2-4.mga9
+ Revision: 1738523
- Cleanup
- Cleanup

* Mon Aug 02 2021 rapsys <rapsys> 2.4.2-3.mga9
+ Revision: 1738518
- Move trusted acl in backend
- Hardcode pid file as variable expansion is not supported in it
  See https://lists.freedesktop.org/archives/systemd-devel/2013-April/010598.html
- Fix tabs
- Fix tabs
- Fix tabs
- Rebuild with fixed config
- Remove metrics backend
- Add metrics backend for prometheus-exporter

* Mon Aug 02 2021 rapsys <rapsys> 2.4.2-2.mga9
+ Revision: 1738506
- Mkrel 2
- Fix atomic require
- Fix build deps on arm - missing libatomic
- Update to version 2.4.2
  Use package from official website instead of github
  Add rapsys private key support patch
  Rename configuration in .conf
  Split utils in a separate package
  Use systemd logging
  Use apache like logrotate
  Use macros to create service user
  Drop atomic-devel build required for armv7hl aarch64
+ bcornec <bcornec>
- Fix build deps on arm - missing libatomic
- Import haproxy using spec example from Julien Pivotto <roidelapluie@inuits.eu> at https://github.com/roidelapluie/haproxy-rpm/blob/master/haproxy.spec but greatly modified !
- Created package structure for haproxy.


* Tue Nov 30 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.10-1mdv2011.0
+ Revision: 603973
- update to 1.4.10

* Sat Nov 27 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.9-1mdv2011.0
+ Revision: 601804
- update to 1.4.9

* Fri Jul 23 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.8-1mdv2011.0
+ Revision: 557114
- update to 1.4.8

* Wed Apr 14 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.4-1mdv2010.1
+ Revision: 534796
- Don't define name, version, release on top of spec
- new version 1.4.4

* Sun Apr 04 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.3-1mdv2010.1
+ Revision: 531224
- update to 1.4.3

* Sun Mar 21 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.2-1mdv2010.1
+ Revision: 525988
- Update to new version 1.4.2

* Fri Mar 05 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.1-1mdv2010.1
+ Revision: 514432
- fix source
- update to 1.4.1

* Tue Mar 02 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.4.0-1mdv2010.1
+ Revision: 513327
- Update to 1.4.0
- Fix License
- Clean spec

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.22-1mdv2010.1
+ Revision: 462704
- update to new version 1.3.22

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.21-1mdv2010.1
+ Revision: 462696
- update to new version 1.3.21

* Tue Jul 28 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.19-1mdv2010.0
+ Revision: 402533
- update to new version 1.3.19

* Sat Jun 27 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.18-1mdv2010.0
+ Revision: 389589
- Update to new version 1.3.18
- Use Mandriva server CFLAGS

* Thu Apr 16 2009 Anne Nicolas <ennael@mandriva.org> 1.3.17-2mdv2009.1
+ Revision: 367606
- fix initrddir macro for MES 5 compatibility

* Wed Apr 15 2009 Anne Nicolas <ennael@mandriva.org> 1.3.17-1mdv2009.1
+ Revision: 367278
- fix group
- import haproxy


